@@ -4,3 +4,6 @@
 /* Version number of package */
 #undef VERSION
 
+@BOTTOM@
+
+#include "cxxconfig.h"
