@@ -1,10 +1,26 @@
-/*
-This file is licensed to you under the license specified in the included file
-`LICENSE'. Look there for further details.
-*/
+/**
+ * Copyright (C) 1999, 2000, 2001  Free Software Foundation, Inc.
+ *
+ * This file is part of GNU gengetopt 
+ *
+ * GNU gengetopt is free software; you can redistribute it and/or modify 
+ * it under the terms of the GNU General Public License as published by 
+ * the Free Software Foundation; either version 2, or (at your option) 
+ * any later version. 
+ *
+ * GNU gengetopt is distributed in the hope that it will be useful, but 
+ * WITHOUT ANY WARRANTY; without even the implied warranty of 
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
+ * Public License for more details. 
+ *
+ * You should have received a copy of the GNU General Public License along 
+ * with gengetopt; see the file COPYING. If not, write to the Free Software 
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 
+ */
 
 #include <stdlib.h>
 #include <stdio.h>
+#include <string.h>
 
 #include "argsdef.h"
 #include "ggos.h"
@@ -18,6 +34,7 @@ extern char * gengetopt_version;
 extern char * gengetopt_purpose;
 
 static int tab_indentation ; /* tab indentation level */
+static int handle_error; /* should I handle errors, by exit(1) */
 
 static char *create_filename (char *name, char *ext);
 static FILE *open_outputfile (char *filename);
@@ -26,6 +43,7 @@ static void inc_indent() ;
 static void dec_indent() ;
 static void check_option_given( char *var_arg,
                                 char *long_opt, char short_opt ) ;
+static void generate_error_handle();
 
 #define ARGS_STRUCT "args_info"
 #define ARGS_STRUCT_NAME PACKAGE "_" ARGS_STRUCT
@@ -148,7 +166,8 @@ int
 generate_cmdline_parser (char *function_name, short unamed_options,
                          char *filename, char *header_ext, char *c_ext,
                          int long_help, int no_handle_help,
-                         int no_handle_version, char **comment)
+                         int no_handle_version,
+                         int no_handle_error, char **comment)
 {
   long max_long, max_short, w;
   struct gengetopt_option * opt;
@@ -169,7 +188,9 @@ generate_cmdline_parser (char *function_name, short unamed_options,
   header_filename = create_filename (filename, header_ext) ;
   c_filename = create_filename (filename, c_ext) ;
 
+  /* global static fields */
   tab_indentation = 0;
+  handle_error = (! no_handle_error);
 
 # define foropt for (opt = gengetopt_options;             \
 		     opt != (struct gengetopt_option *)0; \
@@ -602,6 +623,20 @@ inc_indent ();
 
   printf ("\n");
 
+  /* the following generated instructions are useful, when the
+     parser is called more than once. 
+     Suggested by Eric H Kinzie <ekinzie@cmf.nrl.navy.mil> */
+  indent ();
+  printf ("optarg = 0;\n");
+  indent ();
+  printf ("optind = 1;\n");
+  indent ();
+  printf ("opterr = 1;\n");
+  indent ();
+  printf ("optopt = '?';\n");
+
+  printf ("\n");
+
   indent ();
   printf ("while (1)\n");
   inc_indent ();
@@ -748,7 +783,8 @@ inc_indent ();
   indent ();
   printf ("/* `getopt_long' already printed an error message.  */\n");
   indent ();
-  printf ("exit (1);\n\n");
+  generate_error_handle ();
+  printf ("\n");
   
   dec_indent ();
   indent ();
@@ -796,7 +832,8 @@ inc_indent ();
   printf ("if ( missing_required_options )\n");
   inc_indent ();
   indent ();
-  printf ("exit (1);\n\n");
+  generate_error_handle ();
+  printf ("\n");
   dec_indent ();
 
   /* now handle unamed options */
@@ -880,9 +917,7 @@ check_option_given( char *var_arg, char *long_opt, char short_opt )
   indent ();
   printf ("clear_args ();\n");
   indent ();
-  printf ("%s_print_help ();\n", parser_function_name);
-  indent ();
-  printf ("exit (1);\n");
+  generate_error_handle ();
   dec_indent ();
   indent ();
   printf ("}\n");
@@ -890,3 +925,12 @@ check_option_given( char *var_arg, char *long_opt, char short_opt )
   indent ();
   printf ("%s->%s_given = 1;\n", ARGS_STRUCT, var_arg);
 }
+
+void
+generate_error_handle()
+{
+  if (handle_error)
+    printf ("exit (1);\n");
+  else
+    printf ("return (1);\n");
+}
