@@ -17,7 +17,7 @@
 #define	TOK_CHAR	267
 #define	TOK_ARGTYPE	268
 
-#line 7 "parser.y"
+#line 22 "parser.y"
 
 #include <stdlib.h>
 #include <string.h>
@@ -39,7 +39,7 @@ extern int yylex () ;
 #define check_result \
 	if (o) { switch (o) { case 1: yyerror ("not enough memory"); break; case 2: yyerror ("long option redefined"); break; case 3: yyerror ("short option redefined"); break; case 4: yyerror ("bug found!!"); break; } YYERROR; }
 
-#line 29 "parser.y"
+#line 44 "parser.y"
 typedef union {
 char * str;
 char chr;
@@ -110,8 +110,8 @@ static const short yyrhs[] = {    -1,
 
 #if YYDEBUG != 0
 static const short yyrline[] = { 0,
-    56,    57,    61,    62,    66,    69,    73,    74,    78,    82,
-    85,    88,    90,    94,    98
+    71,    72,    76,    77,    81,    84,    88,    89,    93,    97,
+   100,   103,   105,   109,   113
 };
 #endif
 
@@ -171,7 +171,7 @@ static const short yycheck[] = {     0,
     10,    -1,    -1,    -1,    17
 };
 /* -*-C-*-  Note some compilers choke on comments on `#line' lines.  */
-#line 3 "//usr/lib/bison.simple"
+#line 3 "/usr/lib/bison.simple"
 /* This file comes from bison-1.28.  */
 
 /* Skeleton output parser for bison,
@@ -385,7 +385,7 @@ __yy_memcpy (char *to, char *from, unsigned int count)
 #endif
 #endif
 
-#line 217 "//usr/lib/bison.simple"
+#line 217 "/usr/lib/bison.simple"
 
 /* The user can define YYPARSE_PARAM as the name of an argument to be passed
    into yyparse.  The argument should have type void *.
@@ -714,52 +714,52 @@ yyreduce:
   switch (yyn) {
 
 case 5:
-#line 66 "parser.y"
+#line 81 "parser.y"
 { yyval.str = yyvsp[0].str; ;
     break;}
 case 6:
-#line 69 "parser.y"
+#line 84 "parser.y"
 { yyval.str = yyvsp[0].str; ;
     break;}
 case 7:
-#line 73 "parser.y"
+#line 88 "parser.y"
 { yyval.bool = 1; ;
     break;}
 case 8:
-#line 74 "parser.y"
+#line 89 "parser.y"
 { yyval.bool = 0; ;
     break;}
 case 9:
-#line 78 "parser.y"
+#line 93 "parser.y"
 { if (gengetopt_package_given) { yyerror ("package redefined"); YYERROR; } else { gengetopt_package_given = 1; if (gengetopt_define_package (yyvsp[0].str)) { yyerror ("not enough memory"); YYERROR; } } ;
     break;}
 case 10:
-#line 82 "parser.y"
+#line 97 "parser.y"
 { if (gengetopt_version_given) { yyerror ("version redefined"); YYERROR; } else { gengetopt_version_given = 1; if (gengetopt_define_version (yyvsp[0].str)) { yyerror ("not enough memory"); YYERROR; } } ;
     break;}
 case 11:
-#line 85 "parser.y"
+#line 100 "parser.y"
 { if (gengetopt_purpose_given) { yyerror ("purpose redefined"); YYERROR; } else { gengetopt_purpose_given = 1; if (gengetopt_define_purpose (yyvsp[0].str)) { yyerror ("not enough memory"); YYERROR; } } ;
     break;}
 case 12:
-#line 88 "parser.y"
+#line 103 "parser.y"
 { if (gengetopt_purpose_given) { yyerror ("purpose redefined"); YYERROR; } else { gengetopt_purpose_given = 1; if (gengetopt_define_purpose (yyvsp[0].str)) { yyerror ("not enough memory"); YYERROR; } } ;
     break;}
 case 13:
-#line 90 "parser.y"
+#line 105 "parser.y"
 { int o = gengetopt_add_option (yyvsp[-3].str, yyvsp[-2].chr, yyvsp[-1].str, ARG_NO, 0, 0); check_result; ;
     break;}
 case 14:
-#line 94 "parser.y"
+#line 109 "parser.y"
 { int o = gengetopt_add_option (yyvsp[-4].str, yyvsp[-3].chr, yyvsp[-2].str, ARG_FLAG, yyvsp[0].bool, 0); check_result; ;
     break;}
 case 15:
-#line 98 "parser.y"
+#line 113 "parser.y"
 { int o = gengetopt_add_option (yyvsp[-4].str, yyvsp[-3].chr, yyvsp[-2].str, yyvsp[-1].argtype, 0, yyvsp[0].bool); check_result; ;
     break;}
 }
    /* the action file gets copied in in place of this dollarsign */
-#line 543 "//usr/lib/bison.simple"
+#line 543 "/usr/lib/bison.simple"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -979,7 +979,7 @@ yyerrhandle:
     }
   return 1;
 }
-#line 102 "parser.y"
+#line 117 "parser.y"
 
 
 
