@@ -6,10 +6,9 @@
 char *
 strdup( const char *s )
 {
-  char *res ;
-
-  res = (char *) malloc( strlen( s ) + 1 ) ;
-  strcpy( res, s ) ;
-
-  return res ;
-}
+  char *result = (char*)malloc(strlen(s) + 1);
+  if (result == (char*)0)
+    return (char*)0;
+  strcpy(result, s);
+  return result;
+} 
